==> CodeMirror-0.1.5.zip: CodeMirror/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'CodeMirror Syntaxhighlighting Editor';
$lang['postinstall'] = 'De CodeMirror Module is ge&iuml;nstalleerd';
$lang['needpermission'] = 'U heeft &#039;%s&#039; rechten nodig om deze functie te gebruiken.';
$lang['settingstab'] = 'Instellingen';
$lang['savesettings'] = 'Instellingen opslaan';
$lang['settingssaved'] = 'Instellingen opgeslagen';
$lang['htmltest'] = 'HTML Syntax Test';
$lang['csstest'] = 'CSS Syntax Test';
$lang['phptest'] = 'PHP Syntax Test';
$lang['examplesyntax'] = 'Syntax om mee te testen';
$lang['change'] = 'Wijzig...';
$lang['showlinenumbers'] = 'Regelnummers tonen';
$lang['textwrapping'] = 'Breek lange regels af';
$lang['help'] = '<strong>What does this module do? </strong>
<br/>
The CodeMirror module allows you to edit content, templates and stylesheets using a syntaxhighlighting editor inside your browser.
It can both replace a wysiwyg-module, and act standalone for template/stylesheet editing (only supported in CMSms 1.1+)
<br/><br/>
<strong>How do I use this module?</strong>
You simply install it, and choose it in your admin user preferences. Note, that if you use CMSms 1.1 or above you can
select CodeArea both as a WYSIWYG and as a syntax highlighting editor.';
$lang['utma'] = '156861353.1269027775.1259416186.1264699871.1264703432.275';
$lang['utmz'] = '156861353.1264502019.262.45.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,40950.0.html';
$lang['qca'] = 'P0-431297011-1259416186230';
$lang['utmc'] = '156861353';
$lang['utmb'] = '156861353.1.10.1264703432';
?>

==> CodeMirror-2.0.1.zip: CodeMirror/lang/ext/nl_NL.php <==
<?php
$lang['friendlyname'] = 'CodeMirror Syntaxhighlighting Editor';
$lang['postinstall'] = 'De CodeMirror Module is ge&iuml;nstalleerd';
$lang['needpermission'] = 'U heeft &#039;%s&#039; rechten nodig om deze functie te gebruiken.';
$lang['settingstab'] = 'Instellingen';
$lang['savesettings'] = 'Instellingen opslaan';
$lang['settingssaved'] = 'Instellingen opgeslagen';
$lang['htmltest'] = 'HTML Syntax Test';
$lang['csstest'] = 'CSS Syntax Test';
$lang['phptest'] = 'PHP Syntax Test';
$lang['jstest'] = 'JavaScript Syntax Test';
$lang['examplesyntax'] = 'Syntax om mee te testen';
$lang['change'] = 'Wijzig...';
$lang['showlinenumbers'] = 'Regelnummers tonen';
$lang['textwrapping'] = 'Breek lange regels af';
$lang['automatchparens'] = 'Automatisch bij elkaar horende tags kleuren';
$lang['tabhandling'] = 'Wat te doen bij het indrukken van TAB toets';
$lang['tabdefault'] = 'Laat de browser het bepalen';
$lang['tabindent'] = 'Maak regel inspringing';
$lang['tabspaces'] = 'Voeg spaties toe';
$lang['tabshift'] = 'verplaatst naar rechts, shift-TAB verplaatst naar links';
$lang['cssadditions'] = 'Aanpassingen aan de CodeMirror-css.';
$lang['help'] = '<strong>What does this module do? </strong>
<br/>
The CodeMirror module allows you to edit content, templates and stylesheets using a syntaxhighlighting editor inside your browser.
It can both replace a wysiwyg-module, and act standalone for template/stylesheet editing (only supported in CMSms 1.1+)
<br/><br/>
<strong>How do I use this module?</strong>
You simply install it, and choose it in your admin user preferences. Note, that if you use CMSms 1.1 or above you can
select CodeArea both as a WYSIWYG and as a syntax highlighting editor.';
$lang['utma'] = '156861353.309482405.1295986369.1301153697.1301564370.100';
$lang['utmz'] = '156861353.1300737644.94.26.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/viewtopic.php';
$lang['qca'] = 'P0-1346119953-1295986368908';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
